@@ -71,11 +71,10 @@ int WSAEnumNetworkEvents (SOCKET s,
 
 #endif /* !defined ACE_HAS_WINSOCK2 */
 
-class ACE_WFMO_Reactor_Test;  // Must be out of versioned namespace.
-
 ACE_BEGIN_VERSIONED_NAMESPACE_DECL
 
 // Forward decl.
+class ACE_WFMO_Reactor_Test;
 class ACE_WFMO_Reactor;
 class ACE_Handle_Set;
 
