@@ -1,17 +1,13 @@
-
 //=============================================================================
 /**
  *  @file    Log_Msg_Test.cpp
  *
- *  $Id: Log_Msg_Test.cpp 97138 2013-05-16 17:55:36Z mitza $
- *
  *   This program tests the <ACE_Log_Msg> class in various ways and
  *   also illustrates many of the features of the <ACE_Log_Msg> For
  *   instance, this program tests the <ACE_Log_Msg> abstraction wrt
  *   writing to stderr and to a file.  It also tests writing to user
  *   defined callback objects.
  *
- *
  *  @author Douglas C. Schmidt <schmidt@cs.wustl.edu>
  */
 //=============================================================================
@@ -97,8 +93,12 @@ Logger::log (ACE_Log_Record &log_record)
         ACE_DEBUG ((LM_DEBUG,
                     ACE_TEXT ("Logger::log->%s\n"),
                     log_record.msg_data ()));
-#if !defined (ACE_LACKS_IOSTREAM_TOTALLY)
       else
+#ifdef ACE_LACKS_IOSTREAM_TOTALLY
+        ACE_OS::fprintf (ace_file_stream::instance ()->output_file (),
+                         "Recursive Logger callback = %s\n",
+                         ACE_TEXT_ALWAYS_CHAR (log_record.msg_data ()));
+#else
         *ace_file_stream::instance ()->output_file ()
           << "Recursive Logger callback = "
           << log_record.msg_data ()
@@ -110,15 +110,20 @@ Logger::log (ACE_Log_Record &log_record)
       ACE_TCHAR verbose_msg[ACE_Log_Record::MAXVERBOSELOGMSGLEN];
       int result = log_record.format_msg (ACE_LOG_MSG->local_host (),
                                           ACE_LOG_MSG->flags (),
-                                          verbose_msg);
+                                          verbose_msg,
+                                          ACE_Log_Record::MAXVERBOSELOGMSGLEN);
       if (result == 0)
         {
           if (use_log_msg)
             ACE_DEBUG ((LM_DEBUG,
                         ACE_TEXT ("Logger::log->%s\n"),
                         verbose_msg));
-#if !defined (ACE_LACKS_IOSTREAM_TOTALLY)
           else
+#ifdef ACE_LACKS_IOSTREAM_TOTALLY
+            ACE_OS::fprintf (ace_file_stream::instance ()->output_file (),
+                             "Recursive Logger callback = %s\n",
+                             ACE_TEXT_ALWAYS_CHAR (log_record.msg_data ()));
+#else
             *ace_file_stream::instance ()->output_file ()
               << "Recursive Logger callback = "
               << log_record.msg_data ()
@@ -241,7 +246,7 @@ test_log_msg_features (const ACE_TCHAR *program)
       big[index] = alphabet[i % j];
     }
   big[ACE_Log_Record::MAXLOGMSGLEN] = ACE_TEXT ('\0');
-  ACE_DEBUG ((LM_INFO, ACE_TEXT ("This is too big: %s\n"), big));
+  ACE_DEBUG ((LM_INFO, ACE_TEXT ("This is too big:%l %s\n"), big));
 
   ACE_HEX_DUMP((LM_INFO, (const char*)big, ACE_Log_Record::MAXLOGMSGLEN ));
 
@@ -642,7 +647,7 @@ Log_Spec_Verify::log (ACE_Log_Record &log_record)
           // Check if we have a string, exact length could vary
           if (b != log_record.msg_data () && ACE_OS::strlen (b) < 15)
             {
-              ACE_ERROR ((LM_ERROR, ACE_TEXT ("Test %s failed; expected %d\n"),
+              ACE_ERROR ((LM_ERROR, ACE_TEXT ("ERROR: Test %s failed; expected %d\n"),
                           log_record.msg_data (), ACE_OS::strlen (b)));
               ++this->fail_;
             }
@@ -665,8 +670,18 @@ Log_Spec_Verify::log (ACE_Log_Record &log_record)
             case (LM_EMERGENCY): expect = ACE_TEXT("!"); break;
             default: expect = ACE_TEXT("?"); break;
           }
-
         }
+      else if (ACE_OS::strncmp (b, ACE_TEXT ("l6:"), 3) == 0)
+      {
+        // After a l6 there shouldn't be a space
+        b += 1;
+        if (b != log_record.msg_data () && ACE_OS::strncmp (b, ACE_TEXT (" "), 1) == 0)
+          {
+            ACE_ERROR ((LM_ERROR, ACE_TEXT ("ERROR: Test %s failed; expected no space before the time\n"),
+                       log_record.msg_data ()));
+            ++this->fail_;
+          }
+      }
       else
         {
           ACE_ERROR ((LM_ERROR,
@@ -677,7 +692,7 @@ Log_Spec_Verify::log (ACE_Log_Record &log_record)
 
       if (b != log_record.msg_data () && expect && ACE_OS::strcmp (b, expect) != 0)
         {
-          ACE_ERROR ((LM_ERROR, ACE_TEXT ("Test %s failed; expected %s\n"),
+          ACE_ERROR ((LM_ERROR, ACE_TEXT ("ERROR: Test %s failed; expected %s\n"),
                       log_record.msg_data (), expect));
           ++this->fail_;
         }
@@ -697,9 +712,9 @@ Log_Spec_Verify::result (void)
     ACE_ERROR ((LM_ERROR, ACE_TEXT ("%d logging specifier tests failed!\n"),
                 this->fail_));
 
-  if (this->tests_ != 15)
+  if (this->tests_ != 19)
   {
-    ACE_ERROR ((LM_ERROR, ACE_TEXT ("Expected number of tests run is %d, not 15!\n"),
+    ACE_ERROR ((LM_ERROR, ACE_TEXT ("Expected number of tests run is %d, not 19!\n"),
                 this->tests_));
     ++this->fail_;
   }
@@ -715,12 +730,12 @@ test_format_specs (void)
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%*ISTART INDENTING %{\n"), 4));
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%IONE%{\n")));
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%ITWO%{\n")));
-  ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%ITHREE\n")));
+  ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%ITHREE%*Iwp == 1\n"), 1));
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%}%ITWO\n")));
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%}%IONE\n")));
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%}%IENDINDENTING\n")));
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%W\n"), ACE_TEXT_WIDE ("My string test\n")));
-  ACE_TCHAR* nill_string = 0;
+  ACE_WCHAR_T *nill_string = 0;
   char* char_nill_string = 0;
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%W\n"), nill_string));
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%s\n"), nill_string));
@@ -730,13 +745,6 @@ test_format_specs (void)
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%m %p\n"), ACE_TEXT("perror")));
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%S\n"), SIGINT));
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%S\n"), ACE_NSIG));
-  ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%D\n")));
-  ACE_Time_Value tv = ACE_OS::gettimeofday ();
-  tv += ACE_Time_Value (25*60*60); // + 25 hours
-  ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%#D\n"), &tv));
-  ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%T\n")));
-  ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("%#T\n"), &tv));
-
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("thread id %t\n")));
 
   Log_Spec_Verify  verifier;
@@ -747,9 +755,15 @@ test_format_specs (void)
   ACE_LOG_MSG->linenum (42);
   ACE_LOG_MSG->file ("Log_Msg_Test.cpp");
 
-  ACE_LOG_MSG->log (LM_DEBUG, ACE_TEXT ("l1:%l"));
-  ACE_LOG_MSG->log (LM_DEBUG, ACE_TEXT ("l2:%5l"));
-  ACE_LOG_MSG->log (LM_DEBUG, ACE_TEXT ("l3N1:%0*l,%.7N"), 4);
+#ifdef ACE_LACKS_VA_FUNCTIONS
+#define LOG_ARGS
+#else
+#define LOG_ARGS(X) X
+#endif
+
+  ACE_LOG_MSG->log LOG_ARGS ((LM_DEBUG, ACE_TEXT ("l1:%l")));
+  ACE_LOG_MSG->log LOG_ARGS ((LM_DEBUG, ACE_TEXT ("l2:%5l")));
+  ACE_LOG_MSG->log LOG_ARGS ((LM_DEBUG, ACE_TEXT ("l3N1:%0*l,%.7N"), 4));
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("l4:%T")));
 
   ACE_LOG_MSG->priority_mask (LM_SHUTDOWN |
@@ -776,6 +790,14 @@ test_format_specs (void)
   ACE_DEBUG ((LM_ALERT, ACE_TEXT ("l5:%.1M")));
   ACE_DEBUG ((LM_EMERGENCY, ACE_TEXT ("l5:%.1M")));
 
+  ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("l6:%D\n")));
+  ACE_Time_Value tv = ACE_OS::gettimeofday ();
+  tv += ACE_Time_Value (25*60*60); // + 25 hours
+  ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("l6:%#D\n"), &tv));
+
+  ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("l6:%T\n")));
+  ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("l6:%#T\n"), &tv));
+
   ACE_LOG_MSG->msg_ostream (ace_file_stream::instance ()->output_file ());
   ACE_LOG_MSG->msg_callback (0);
   ACE_LOG_MSG->set_flags (ACE_Log_Msg::OSTREAM);
